<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:plm="http://www.plmxml.org/Schemas/PLMXMLSchema"
	xmlns:cim="http://www.coolemall.eu/DEBBComponent" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">

	<!-- Importing xslt for translating debb components -->
	<xsl:import href="DEBBComponentTranslator.xsl" />

	<!-- Specification of the output document -->
	<xsl:output method="xml" version="1.0" encoding="UTF-8"
		indent="yes" />

	<!-- Root of the PLM XML document -->
	<xsl:variable name="rootDoc" select="/" />

	<!-- Default DEBBComponents file name (used if it is not specified in PLM 
		XML file) -->
	<xsl:variable name="defaultDEBBComponentsFileName" select="'DEBBComponents.xml'" />


	<xsl:template match="/">
		<xsl:element name="environment">
			<xsl:attribute name="xsi:noNamespaceSchemaLocation">DCWormsResSchema.xsd</xsl:attribute>
			<xsl:element name="resources">
				<xsl:element name="scheduler"></xsl:element>
				<xsl:apply-templates select="//plm:InstanceGraph" />
			</xsl:element>
		</xsl:element>
	</xsl:template>

	<xsl:template match="plm:InstanceGraph">
		<xsl:variable name="rootRef" select="@rootRefs" />
		<xsl:apply-templates select="plm:ProductInstance[@id=$rootRef]" />
	</xsl:template>

	<xsl:template match="plm:ProductInstance">
		<xsl:variable name="partRef" select="@partRef" />
		<xsl:variable name="id" select="translate($partRef, '#', '')" />

		<xsl:if test="not (starts-with(@name, 'Sensor'))">
			<!-- We have to get rid of sensors, which make only problems here -->
			<xsl:element name="computingElement">
				<xsl:attribute name="test"><xsl:value-of select="@name" /></xsl:attribute>
				<xsl:apply-templates select="//plm:ProductRevisionView[@id=$id]" />
			</xsl:element>
		</xsl:if>
	</xsl:template>

	<xsl:template match="plm:ProductRevisionView">
		<xsl:variable name="tokenizedText" select="tokenize(@instanceRefs, ' ')" />
		<xsl:variable name="debbLevel"
			select="plm:UserData/plm:UserValue[@title='DEBBLevel']/@value" />
		<xsl:attribute name="class">
			<xsl:value-of select="$debbLevel" />
		</xsl:attribute>
		<xsl:variable name="debbComponentId"
			select="plm:UserData/plm:UserValue[@title='DEBBComponentId']/@value" />
		<xsl:variable name="debbComponentFile"
			select="plm:UserData/plm:UserValue[@title='DEBBComponentFile']/@value" />

		<xsl:attribute name="name">
			<xsl:value-of select="$debbComponentId" />
		</xsl:attribute>
		<xsl:choose>
			<xsl:when test="debbComponentFile != ''">
				<xsl:variable name="nestedDoc" select="document($debbComponentFile)" />
				<xsl:apply-templates select="$nestedDoc//*[ComponentId=$debbComponentId]" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="nestedDoc"
					select="document($defaultDEBBComponentsFileName)" />
				<xsl:apply-templates select="$nestedDoc//*[ComponentId=$debbComponentId]" />
			</xsl:otherwise>
		</xsl:choose>


		<xsl:for-each select="1 to count($tokenizedText)">
			<xsl:variable name="index" select="." />
			<xsl:apply-templates
				select="$rootDoc//plm:ProductInstance[@id=$tokenizedText[$index]]" />
		</xsl:for-each>
	</xsl:template>
</xsl:stylesheet>

